@@ -1,7 +1,9 @@
 import numpy
 
 
-def wrapped_difference(delta, period=2 * numpy.pi, discont=None):
+def wrapped_difference(
+    delta: numpy.ndarray, period=2 * numpy.pi, discont=None
+) -> numpy.ndarray:
     """
     Calculate the wrapped difference for a given delta for a periodic variable.
     E.g. if the difference between two angles measured in degrees is 359 we
@@ -24,7 +26,7 @@ def wrapped_difference(delta, period=2 * numpy.pi, discont=None):
     if discont is None:
         discont = period / 2
 
-    with numpy.errstate(invalid="ignore"):
-        out = (delta + period - discont) % period - period + discont
-
-    return out
+    mask = numpy.isfinite(delta)
+    output = numpy.full_like(delta, numpy.nan)
+    output[mask] = (delta[mask] + period - discont) % period - period + discont
+    return output
